**Example 1: 查询应用关联日志配置项信息**



Input: 

```
tccli tsf DescribeApplicationBusinessLogConfig --cli-unfold-argument  \
    --ApplicationId xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "5d996e5507e42d5970cd2e25ed5267a"
    }
}
```

